setup static method
define host and prefix so that on every request only specify endpoint
Implementation
static void setup({required String baseUrl}) {
_baseUri = Uri.parse(baseUrl);
}
define host and prefix so that on every request only specify endpoint
static void setup({required String baseUrl}) {
_baseUri = Uri.parse(baseUrl);
}