NetworkLogModel class

Model representing a single network log entry. This is backend-agnostic and works for both http and dio.

Constructors

NetworkLogModel({required String method, required String url, required Map<String, dynamic> requestHeaders, dynamic requestBody, required Map<String, dynamic> responseHeaders, dynamic responseBody, required int statusCode, required DateTime timestamp, required Duration duration})
const

Properties

duration Duration
final
hashCode int
The hash code for this object.
no setterinherited
method String
final
requestBody → dynamic
final
requestHeaders Map<String, dynamic>
final
responseBody → dynamic
final
responseHeaders Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final
timestamp DateTime
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited