UnifiedRequest class
Lightweight request model used by unified interceptors.
Constructors
Properties
- body ↔ dynamic
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
↔ Map<
String, String> -
getter/setter pair
- method → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startedAt ↔ DateTime?
-
Optional timestamp that can be used by interceptors
(e.g. for measuring request duration).
getter/setter pair
- uri ↔ Uri
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited