startedAt property
Optional timestamp that can be used by interceptors (e.g. for measuring request duration).
Implementation
DateTime? startedAt;
Optional timestamp that can be used by interceptors (e.g. for measuring request duration).
DateTime? startedAt;