NetworkLogInterceptor class
Unified interceptor that records all HTTP/Dio traffic into NetworkLogStorage.
Because it works with UnifiedRequest/UnifiedResponse/UnifiedError, it is automatically reused for both http and dio stacks.
- Inheritance
-
- Object
- UnifiedInterceptor
- NetworkLogInterceptor
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
UnifiedError error) → Future< UnifiedError> -
override
-
onRequest(
UnifiedRequest request) → Future< UnifiedRequest> -
override
-
onResponse(
UnifiedResponse response) → Future< UnifiedResponse> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited