Failure class
Inherited from Result class This class represent Failed response from the API request
Constructors
- Failure(UnifiedHttpClientEnum unifiedHttpClientEnum, String message)
-
constructor
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
error message from backend or our standard message as per status code
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unifiedHttpClientEnum → UnifiedHttpClientEnum
-
check what was the reason behind api failure
final
Methods
-
fold<
T> (T onFailure(Failure failure), T onSuccess(Never value)) → T -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited